@@ -33,9 +33,6 @@
 #include <glib.h>
 #include <errno.h>
 #include <time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
@@ -94,9 +91,6 @@ static GHashTable *server_cache = NULL;
 #define SERVER_CACHE_REAP_TIMEOUT (30*60)
 static guint server_cache_reap_timeout = 0;
 
-/* The magic "default workgroup" hostname */
-#define DEFAULT_WORKGROUP_NAME "X-GNOME-DEFAULT-WORKGROUP"
-
 
 /* 5 minutes before we re-read the workgroup cache again */
 #define WORKGROUP_CACHE_TIMEOUT (5*60)
@@ -280,7 +274,7 @@ add_old_servers (gpointer key,
 
 
 static gboolean
-server_cache_reap_cb (void)
+server_cache_reap_cb ()
 {
      	int size;
 	GPtrArray *servers;
@@ -312,7 +306,7 @@ schedule_server_cache_reap (void)
 {
 	if (server_cache_reap_timeout == 0) {
 		server_cache_reap_timeout = g_timeout_add (SERVER_CACHE_REAP_TIMEOUT*1000,
-							   (GSourceFunc)server_cache_reap_cb, NULL);
+							   server_cache_reap_cb, NULL);
 	}
 }
 
@@ -512,9 +506,7 @@ update_workgroup_cache (void)
 	dir = smb_context->opendir (smb_context, "smb://");
 	if (dir != NULL) {
 		while ((dirent = smb_context->readdir (smb_context, dir)) != NULL) {
-			if (dirent->smbc_type == SMBC_WORKGROUP &&
-			    dirent->name != NULL &&
-			    strlen (dirent->name) > 0) {
+			if (dirent->smbc_type == SMBC_WORKGROUP) {
 				g_hash_table_insert (workgroups,
 						     g_ascii_strdown (dirent->name, -1),
 						     GINT_TO_POINTER (1));
@@ -554,9 +546,7 @@ smb_uri_type (GnomeVFSURI *uri)
 	    strcmp (uri->text, "/") == 0) {
 		/* smb://foo/ */
 		update_workgroup_cache ();
-		if (!g_ascii_strcasecmp(toplevel->host_name,
-					DEFAULT_WORKGROUP_NAME) ||
-		    g_hash_table_lookup (workgroups, toplevel->host_name)) {
+		if (g_hash_table_lookup (workgroups, toplevel->host_name)) {
 			return SMB_URI_WORKGROUP;
 		} else {
 			return SMB_URI_SERVER;
@@ -566,9 +556,7 @@ smb_uri_type (GnomeVFSURI *uri)
 	if (first_slash == NULL) {
 		/* smb://foo/bar */
 		update_workgroup_cache ();
-		if (!g_ascii_strcasecmp(toplevel->host_name,
-					DEFAULT_WORKGROUP_NAME) ||
-		    g_hash_table_lookup (workgroups, toplevel->host_name)) {
+		if (g_hash_table_lookup (workgroups, toplevel->host_name)) {
 			return SMB_URI_SERVER_LINK;
 		} else {
 			return SMB_URI_SHARE;
@@ -595,21 +583,27 @@ static gboolean
 try_init (void)
 {
 	char *path;
-	struct stat statbuf;
 
 	LOCK_SMB();
 
-	/* We used to create an empty ~/.smb/smb.conf to get
-	 * default settings, but this breaks a lot of smb.conf
-	 * configurations, so we remove this again. If you really
-	 * need an empty smb.conf, put a newline in it */
+	/* TODO: Why is this needed? */
+	/* Create an empty ~/.smb/smb.conf */
+	path = g_build_filename (G_DIR_SEPARATOR_S, g_get_home_dir (),
+			".smb", NULL);
+	if (g_file_test (path, G_FILE_TEST_IS_DIR) == FALSE) {
+		mkdir (path, 0700);
+	} else {
+		chmod (path, 0700);
+	}
+	g_free (path);
+
 	path = g_build_filename (G_DIR_SEPARATOR_S, g_get_home_dir (),
 			".smb", "smb.conf", NULL);
-
-	if (stat (path, &statbuf) == 0) {
-		if (S_ISREG (statbuf.st_mode) &&
-		    statbuf.st_size == 0) {
-			unlink (path);
+	if (g_file_test (path, G_FILE_TEST_IS_REGULAR) == FALSE) {
+		int fd;
+		fd = creat (path, 0600);
+		if (fd > 0) {
+			close (fd);
 		}
 	}
 	g_free (path);
@@ -627,11 +621,6 @@ try_init (void)
 			smbc_free_context (smb_context, FALSE);
 			smb_context = NULL;
 		}
-
-#if defined(HAVE_SAMBA_FLAGS) && defined(SMB_CTX_FLAG_USE_KERBEROS) && defined(SMB_CTX_FLAG_FALLBACK_AFTER_KERBEROS)
-		smb_context->flags |= SMB_CTX_FLAG_USE_KERBEROS | SMB_CTX_FLAG_FALLBACK_AFTER_KERBEROS;
-#endif
-		
 	}
 
 	server_cache = g_hash_table_new_full (server_hash,
@@ -847,7 +836,7 @@ init_auth (GnomeVFSURI *uri)
 }
 
 static gboolean
-auth_failed (void)
+auth_failed ()
 {
 	return cache_access_failed &&
 		(errno == EACCES || errno == EPERM) &&
@@ -893,7 +882,7 @@ auth_fn (const char *server_name, const char *share_name,
 		tmp = strchr (current_toplevel_uri->user_name, ';');
 		if (tmp != NULL) {
 			domain = g_strndup (current_toplevel_uri->user_name,
-					    tmp - current_toplevel_uri->user_name);
+					    current_toplevel_uri->user_name - tmp);
 			username = g_strdup (tmp + 1);
 		} else {
 			username = g_strdup (current_toplevel_uri->user_name);
@@ -1525,6 +1514,9 @@ static gboolean
 do_is_local (GnomeVFSMethod *method,
 	     const GnomeVFSURI *uri)
 {
+	DEBUG_SMB (("do_is_local(): %s\n", gnome_vfs_uri_to_string (uri,
+					GNOME_VFS_URI_HIDE_NONE)));
+
 	return FALSE;
 }
 
@@ -1556,8 +1548,6 @@ do_open_directory (GnomeVFSMethod *method,
 
 {
 	DirectoryHandle *directory_handle;
-	GnomeVFSURI *new_uri = NULL;
-	const char *host_name;
 	char *path;
 	SmbUriType type;
 	SMBCFILE *dir;
@@ -1585,19 +1575,6 @@ do_open_directory (GnomeVFSMethod *method,
 	    type == SMB_URI_SERVER_LINK) {
 		return GNOME_VFS_ERROR_NOT_A_DIRECTORY;
 	}
-
-	/* if it is the magic default workgroup name, map it to the 
-	 * SMBCCTX's workgroup, which comes from the smb.conf file. */
-	host_name = gnome_vfs_uri_get_host_name (uri);
-	if (type == SMB_URI_WORKGROUP && host_name != NULL &&
-	    !g_ascii_strcasecmp(host_name, DEFAULT_WORKGROUP_NAME)) {
-		new_uri = gnome_vfs_uri_dup (uri);
-		gnome_vfs_uri_set_host_name (new_uri,
-					     smb_context->workgroup
-					     ? smb_context->workgroup
-					     : "WORKGROUP");
-		uri = new_uri;
-	}
 		
 	path = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_USER_NAME | GNOME_VFS_URI_HIDE_PASSWORD);
 
@@ -1614,14 +1591,11 @@ do_open_directory (GnomeVFSMethod *method,
 	if (dir == NULL) {
 		UNLOCK_SMB();
 		g_free (path);
-		if (new_uri) gnome_vfs_uri_unref (new_uri);
 		return gnome_vfs_result_from_errno ();
 	}
 
 	UNLOCK_SMB();
 
-	if (new_uri) gnome_vfs_uri_unref (new_uri);
-
 	/* Construct the handle */
 	directory_handle = g_new0 (DirectoryHandle, 1);
 	directory_handle->dir = dir;
@@ -1723,8 +1697,6 @@ do_read_directory (GnomeVFSMethod *method,
 	} while (entry->smbc_type == SMBC_COMMS_SHARE ||
 		 entry->smbc_type == SMBC_IPC_SHARE ||
 		 entry->smbc_type == SMBC_PRINTER_SHARE ||
-		 entry->name == NULL ||
-		 strlen (entry->name) == 0 ||
 		 (entry->smbc_type == SMBC_FILE_SHARE &&
 		  is_hidden_entry (entry->name)));
 		
@@ -1738,8 +1710,7 @@ do_read_directory (GnomeVFSMethod *method,
 	switch (entry->smbc_type) {
 	case SMBC_FILE_SHARE:
 		file_info->valid_fields = file_info->valid_fields
-			| GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE
-			| GNOME_VFS_FILE_INFO_FIELDS_TYPE;
+			| GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE;
 		file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
 		file_info->mime_type = g_strdup ("x-directory/smb-share");
 		break;
